-- Dissection count postdissector

-- We need to extract the frame number
frame_num_f = Field.new("frame.number")

-- Declare our "protocol"
di_proto = Proto("dissection_info", "Dissection information")

-- Create the fields for our "protocol"
di_count_F = ProtoField.int32("dissection_info.count",
    "Number of times this frame has been dissected",
    base.DEC)

-- Add the field to the "protocol"
di_proto.fields = { di_count_F }

-- Track our dissection counts
dcounts = {}

function di_proto.init()
    dcounts = {}
end

-- Create our postdissector
function di_proto.dissector(buffer, pinfo, tree)
    -- Obtain the current values the protocol fields
    local frame_num = frame_num_f()

    if (frame_num) then
        local subtree = tree:add("Dissection Count")
        local fnv = frame_num.value
        
        if (dcounts[fnv] == nil) then
            dcounts[fnv] = 0
        end
        dcounts[fnv] = dcounts[fnv] + 1
        subtree:add(di_count_F, dcounts[fnv])
    end
end

-- Register our protocol as a postdissector
register_postdissector(di_proto)